@@ -1,11 +1,11 @@
 import inspect
 import functools
 import warnings
-from distutils.version import LooseVersion
 
 import uuid
 import marshmallow as ma
 from marshmallow import validate, fields
+from packaging.version import Version
 from sqlalchemy.dialects import postgresql, mysql, mssql
 from sqlalchemy.orm import SynonymProperty
 import sqlalchemy as sa
@@ -14,7 +14,7 @@ from .exceptions import ModelConversionError
 from .fields import Related, RelatedList
 
 
-_META_KWARGS_DEPRECATED = LooseVersion(ma.__version__) >= LooseVersion("3.10.0")
+_META_KWARGS_DEPRECATED = Version(ma.__version__) >= Version("3.10.0")
 
 
 def _is_field(value):
@@ -105,6 +105,7 @@ class ModelConverter:
         mysql.INTEGER: fields.Integer,
         mysql.DATETIME: fields.DateTime,
         mssql.BIT: fields.Integer,
+        mssql.UNIQUEIDENTIFIER: fields.UUID,
     }
     DIRECTION_MAPPING = {"MANYTOONE": False, "MANYTOMANY": True, "ONETOMANY": True}
 
@@ -263,7 +264,7 @@ class ModelConverter:
                 if hasattr(data_type, "impl"):
                     return self._get_field_class_for_data_type(data_type.impl)
                 raise ModelConversionError(
-                    "Could not find field column of type {}.".format(types[0])
+                    f"Could not find field column of type {types[0]}."
                 )
         return field_cls
 
@@ -312,17 +313,22 @@ class ModelConverter:
         """Add keyword arguments to kwargs (in-place) based on the passed in
         `Column <sqlalchemy.schema.Column>`.
         """
-        if column.nullable:
-            kwargs["allow_none"] = True
-        kwargs["required"] = not column.nullable and not _has_default(column)
+        if hasattr(column, "nullable"):
+            if column.nullable:
+                kwargs["allow_none"] = True
+            kwargs["required"] = not column.nullable and not _has_default(column)
+        # If there is no nullable attribute, we are dealing with a property
+        # that does not derive from the Column class. Mark as dump_only.
+        else:
+            kwargs["dump_only"] = True
 
-        if hasattr(column.type, "enums"):
+        if hasattr(column.type, "enums") and not kwargs.get("dump_only"):
             kwargs["validate"].append(validate.OneOf(choices=column.type.enums))
 
         # Add a length validator if a max length is set on the column
         # Skip UUID columns
         # (see https://github.com/marshmallow-code/marshmallow-sqlalchemy/issues/54)
-        if hasattr(column.type, "length"):
+        if hasattr(column.type, "length") and not kwargs.get("dump_only"):
             column_length = column.type.length
             if column_length is not None:
                 try:
